@@ -21,7 +21,7 @@ from iminuit import Minuit, describe, Struct
 # <codecell>
 
 def f(x,y,z):
-    return (x-1.)**2 + (y-2.)**2 + (z-3.)**2 -1.
+    return (x-1.)**2 + (y-2*x)**2 + (z-3.*x)**2 -1.
 
 # <markdowncell>
 
@@ -59,6 +59,8 @@ m=Minuit(f, x=2, error_x=0.2, limit_x=(-10.,10.), y=3., fix_y=True, print_level=
 # <codecell>
 
 m.print_param()#or call print_initial_param
+#bonus: if you click the + button on the top left corner it will show latex table
+#which you can copy and paste to your beamer/latex document
 
 # <markdowncell>
 
@@ -128,6 +130,7 @@ print 'covariance', m.covariance
 print 'matrix()', m.matrix() #covariance
 print 'matrix(correlation=True)', m.matrix(correlation=True) #correlation
 m.print_matrix() #correlation
+#again click the + button on the top left corner for latex code
 
 # <markdowncell>
 
@@ -146,15 +149,45 @@ print m.get_fmin().is_valid
 
 # <codecell>
 
+#minos contour
+xminos, zminos, ctr = m.mncontour('x','z')
+fill(*zip(*ctr)) #looks kinda ugly, right?
+
+# <codecell>
+
+#drawing it nicely
+m.draw_mncontour('x','z', nsigma=4);
+
+# <codecell>
+
+#or you can get the gridded data
+x, y, g, r = m.mncontour_grid('x','z', nsigma=3) # r is the raw data
+pcolormesh(x,y,g)
+colorbar()
+
+# <codecell>
+
+#1D value Scan
 x,y = m.profile('x',subtract_min=True);
 plot(x,y) #if you have matplotlib
 
 # <codecell>
 
-x,y,z = m.contour('x','z',subtract_min=True)
+#we also provide convenience wrapper for drawing it
+m.draw_profile('x');
+
+# <codecell>
+
+#2d contour NOT minos contour
+x,y,z = m.contour('x','y',subtract_min=True)
 cs = contour(x,y,z)
 clabel(cs)
 
+# <codecell>
+
+#or a convenience wrapper
+m.draw_contour('x','z');
+
 # <markdowncell>
 
 # ###Hesse and Minos
@@ -206,7 +239,7 @@ from iminuit import Minuit, describe, Struct
 
 # <codecell>
 
-%%cython
+%%cython --force
 cimport cython
 import numpy as np
 cimport numpy as np #overwritten those from python with cython
